==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNode__24ListenerRecord.h <==
// final class gnu.xml.dom.DomNode$ListenerRecord

// class file dependencies
// @dep_class 8d6b3a5a1f041ca6 gnu_xml_dom_DomNode__24ListenerRecord
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_
#define _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_events_EventListener$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$refs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object	_jc_gnu_xml_dom_DomNode__24ListenerRecord$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24ListenerRecord$method$_init$d3513e42d7367e81(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_java_lang_String$object *, struct _jc_object *, jboolean);

// Virtual methods
extern jboolean _jc_gnu_xml_dom_DomNode__24ListenerRecord$method$equals$6bb2e38f2251a97f(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24ListenerRecord$method_info$equals$6bb2e38f2251a97f;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods {
	jboolean	(*equals$6bb2e38f2251a97f)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods	gnu_xml_dom_DomNode__24ListenerRecord;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$refs {
    _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs	gnu_xml_dom_DomNode__24ListenerRecord;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs {
	jboolean	useCapture;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs	gnu_xml_dom_DomNode__24ListenerRecord;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object {
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype _jc_gnu_xml_dom_DomNode__24ListenerRecord$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24ListenerRecord, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24ListenerRecord$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomNode__24ListenerRecord.h <==
// final class gnu.xml.dom.DomNode$ListenerRecord

// class file dependencies
// @dep_class 8d6b3a5a1f041ca6 gnu_xml_dom_DomNode__24ListenerRecord
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_
#define _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_events_EventListener$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$refs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs	_jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object	_jc_gnu_xml_dom_DomNode__24ListenerRecord$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24ListenerRecord$method$_init$d3513e42d7367e81(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_java_lang_String$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_dom_DomNode__24ListenerRecord$method$equals$6bb2e38f2251a97f(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24ListenerRecord$method_info$equals$6bb2e38f2251a97f;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods {
	jboolean	(*equals$6bb2e38f2251a97f)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *, struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vmethods	gnu_xml_dom_DomNode__24ListenerRecord;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_object	*listener;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$refs {
    _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_refs	gnu_xml_dom_DomNode__24ListenerRecord;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs {
	jboolean	useCapture;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24ListenerRecord$sub_nonrefs	gnu_xml_dom_DomNode__24ListenerRecord;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24ListenerRecord$object {
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24ListenerRecord$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24ListenerRecord$vtype _jc_gnu_xml_dom_DomNode__24ListenerRecord$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24ListenerRecord, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24ListenerRecord$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24ListenerRecord_H_ */
